diff --git a/module/VuFind/src/VuFind/Account/Manager.php b/module/VuFind/src/VuFind/Auth/Manager.php
similarity index 98%
rename from module/VuFind/src/VuFind/Account/Manager.php
rename to module/VuFind/src/VuFind/Auth/Manager.php
index ee639492952834d0101f370507e30a78d2157414..079375a864216747aa34c6d8f0180e7bb46c7755 100644
--- a/module/VuFind/src/VuFind/Account/Manager.php
+++ b/module/VuFind/src/VuFind/Auth/Manager.php
@@ -25,8 +25,8 @@
  * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
  * @link     http://www.vufind.org  Main Page
  */
-namespace VuFind\Account;
-use VuFind\Auth\Factory as AuthFactory, VuFind\Config\Reader as ConfigReader,
+namespace VuFind\Auth;
+use VuFind\Config\Reader as ConfigReader,
     VuFind\Connection\Manager as ConnectionManager,
     VuFind\Exception\Auth as AuthException, VuFind\Exception\ILS as ILSException,
     VuFind\Registry, Zend\Session\Container as SessionContainer;
@@ -53,7 +53,7 @@ class Manager
     public function __construct()
     {
         $this->config = ConfigReader::getConfig();
-        $this->auth = AuthFactory::getAuth(
+        $this->auth = Factory::getAuth(
             $this->config->Authentication->method, $this->config
         );
         $this->session = new SessionContainer('Account');
diff --git a/module/VuFind/src/VuFind/Bootstrap.php b/module/VuFind/src/VuFind/Bootstrap.php
index b80a4766ac205ac0174ece48be05fa866230ffd0..554f2316f94f3ae4dcdb10aa5d97063ddd7b51e4 100644
--- a/module/VuFind/src/VuFind/Bootstrap.php
+++ b/module/VuFind/src/VuFind/Bootstrap.php
@@ -26,8 +26,7 @@
  * @link     http://vufind.org   Main Site
  */
 namespace VuFind;
-use VuFind\Account\Manager as AccountManager,
-    VuFind\Cache\Manager as CacheManager,
+use VuFind\Auth\Manager as AuthManager, VuFind\Cache\Manager as CacheManager,
     VuFind\Config\Reader as ConfigReader,
     VuFind\Db\AdapterFactory as DbAdapterFactory,
     VuFind\Registry, VuFind\Theme\Initializer as ThemeInitializer,
@@ -125,17 +124,17 @@ class Bootstrap
      */
     protected function initAccount()
     {
-        $accountManager = new AccountManager();
+        $authManager = new AuthManager();
 
         // Register in service manager:
         $serviceManager = $this->event->getApplication()->getServiceManager();
-        $serviceManager->setService('AccountManager', $accountManager);
+        $serviceManager->setService('AuthManager', $authManager);
 
         // Register in view:
-        $callback = function($event) use ($accountManager) {
+        $callback = function($event) use ($authManager) {
             $serviceManager = $event->getApplication()->getServiceManager();
             $viewModel = $serviceManager->get('viewmanager')->getViewModel();
-            $viewModel->setVariable('account', $accountManager);
+            $viewModel->setVariable('account', $authManager);
         };
         $this->events->attach('dispatch', $callback);
     }
@@ -361,6 +360,6 @@ class Bootstrap
 
         // Check user credentials:
         $serviceManager = $this->event->getApplication()->getServiceManager();
-        $serviceManager->get('AccountManager')->checkForExpiredCredentials();
+        $serviceManager->get('AuthManager')->checkForExpiredCredentials();
     }
 }
\ No newline at end of file
diff --git a/module/VuFind/src/VuFind/Controller/AbstractBase.php b/module/VuFind/src/VuFind/Controller/AbstractBase.php
index 534730cb997c269804c070acf4825ebdb1799979..d461b5fba32dfb45be0c4e71d8f02550c9d67dca 100644
--- a/module/VuFind/src/VuFind/Controller/AbstractBase.php
+++ b/module/VuFind/src/VuFind/Controller/AbstractBase.php
@@ -75,9 +75,9 @@ class AbstractBase extends AbstractActionController
      *
      * @return \VuFind\Account\Manager
      */
-    protected function getAccount()
+    protected function getAuthManager()
     {
-        return $this->getServiceLocator()->get('AccountManager');
+        return $this->getServiceLocator()->get('AuthManager');
     }
 
     /**
@@ -87,7 +87,7 @@ class AbstractBase extends AbstractActionController
      */
     protected function getUser()
     {
-        return $this->getAccount()->isLoggedIn();
+        return $this->getAuthManager()->isLoggedIn();
     }
 
     /**
@@ -132,7 +132,7 @@ class AbstractBase extends AbstractActionController
     protected function catalogLogin()
     {
         // First make sure user is logged in to VuFind:
-        $account = $this->getAccount();
+        $account = $this->getAuthManager();
         if ($account->isLoggedIn() == false) {
             $this->forceLogin();
             return false;
diff --git a/module/VuFind/src/VuFind/Controller/MyResearchController.php b/module/VuFind/src/VuFind/Controller/MyResearchController.php
index 10ec02ecd10e5dd722cc7d941d4d5e295cbe5350..42b5f8a0692eccc64a0fbec93cfbe1fefbb7fba0 100644
--- a/module/VuFind/src/VuFind/Controller/MyResearchController.php
+++ b/module/VuFind/src/VuFind/Controller/MyResearchController.php
@@ -64,7 +64,7 @@ class MyResearchController extends AbstractBase
         // Process login request, if necessary:
         if ($this->params()->fromPost('processLogin')) {
             try {
-                $this->getAccount()->login($this->getRequest()->getPost());
+                $this->getAuthManager()->login($this->getRequest()->getPost());
             } catch (AuthException $e) {
                 $this->flashMessenger()->setNamespace('error')
                     ->addMessage($e->getMessage());
@@ -72,7 +72,7 @@ class MyResearchController extends AbstractBase
         }
 
         // Not logged in?  Force user to log in:
-        if (!$this->getAccount()->isLoggedIn()) {
+        if (!$this->getAuthManager()->isLoggedIn()) {
             return $this->forward()
                 ->dispatch('MyResearch', array('action' => 'Login'));
         }
@@ -103,7 +103,7 @@ class MyResearchController extends AbstractBase
     {
         // If authentication mechanism does not support account creation, send
         // the user away!
-        if (!$this->getAccount()->supportsCreation()) {
+        if (!$this->getAuthManager()->supportsCreation()) {
             return $this->forward()
                 ->dispatch('MyResearch', array('action' => 'Home'));
         }
@@ -121,7 +121,7 @@ class MyResearchController extends AbstractBase
         // Process request, if necessary:
         if (!is_null($this->params()->fromPost('submit', null))) {
             try {
-                $this->getAccount()->create($this->getRequest()->getPost());
+                $this->getAuthManager()->create($this->getRequest()->getPost());
                 return $this->forward()
                     ->dispatch('MyResearch', array('action' => 'Home'));
             } catch (AuthException $e) {
@@ -145,7 +145,7 @@ class MyResearchController extends AbstractBase
     {
         // If this authentication method doesn't use a VuFind-generated login
         // form, force it through:
-        if ($this->getAccount()->getSessionInitiator()) {
+        if ($this->getAuthManager()->getSessionInitiator()) {
             // Don't get stuck in an infinite loop -- if processLogin is already
             // set, it probably means Home action is forwarding back here to
             // report an error!
@@ -183,7 +183,7 @@ class MyResearchController extends AbstractBase
     {
         $serverHelper = new \Zend\View\Helper\ServerUrl();
         $url = $serverHelper->__invoke($this->url()->fromRoute('home'));
-        return $this->redirect()->toUrl($this->getAccount()->logout($url));
+        return $this->redirect()->toUrl($this->getAuthManager()->logout($url));
     }
 
     /**
@@ -194,7 +194,7 @@ class MyResearchController extends AbstractBase
     public function savesearchAction()
     {
         /* TODO:
-        $user = $this->getAccount()->isLoggedIn();
+        $user = $this->getAuthManager()->isLoggedIn();
         if ($user == false) {
             return $this->forceLogin();
         }
@@ -245,7 +245,7 @@ class MyResearchController extends AbstractBase
         $homeLibrary = $this->params()->fromPost('home_library', false);
         if (!empty($homeLibrary)) {
             $user->changeHomeLibrary($homeLibrary);
-            $this->getAccount()->updateSession($user);
+            $this->getAuthManager()->updateSession($user);
             $this->flashMessenger()->setNamespace('info')
                 ->addMessage('profile_update');
         }
@@ -506,7 +506,7 @@ class MyResearchController extends AbstractBase
 
         try {
             $params = new \VuFind\Search\Favorites\Params();
-            $params->setAccountManager($this->getAccount());
+            $params->setAuthManager($this->getAuthManager());
             $params->initFromRequest($this->getRequest()->getQuery());
             $results = new \VuFind\Search\Favorites\Results($params);
             $results->performAndProcessSearch();
diff --git a/module/VuFind/src/VuFind/ILS/Logic/Holds.php b/module/VuFind/src/VuFind/ILS/Logic/Holds.php
index c7450fb7342520e2f897b92709371abd238c3dd1..9bc0f0076d45eda00fa16cf419b8b36206e1a403 100644
--- a/module/VuFind/src/VuFind/ILS/Logic/Holds.php
+++ b/module/VuFind/src/VuFind/ILS/Logic/Holds.php
@@ -52,8 +52,8 @@ class Holds
     /**
      * Constructor
      *
-     * @param \VuFind\Account\Manager $account Account manager object
-     * @param ILSConnection           $catalog A catalog connection
+     * @param \VuFind\Auth\Manager $account Auth manager object
+     * @param ILSConnection        $catalog A catalog connection
      */
     public function __construct($account, $catalog = false)
     {
diff --git a/module/VuFind/src/VuFind/ILS/Logic/TitleHolds.php b/module/VuFind/src/VuFind/ILS/Logic/TitleHolds.php
index 3fbcaabe046150df355ef3b3409450034d55ff46..50608c6b4cd8b4e81aeb04ab5857ef9e9b97717a 100644
--- a/module/VuFind/src/VuFind/ILS/Logic/TitleHolds.php
+++ b/module/VuFind/src/VuFind/ILS/Logic/TitleHolds.php
@@ -52,8 +52,8 @@ class TitleHolds
     /**
      * Constructor
      *
-     * @param \VuFind\Account\Manager $account Account manager object
-     * @param ILSConnection           $catalog A catalog connection
+     * @param \VuFind\Auth\Manager $account Auth manager object
+     * @param ILSConnection        $catalog A catalog connection
      */
     public function __construct($account, $catalog = false)
     {
diff --git a/module/VuFind/src/VuFind/RecordDriver/SolrDefault.php b/module/VuFind/src/VuFind/RecordDriver/SolrDefault.php
index 987563ad05820787aacea4c839e9d9c5b08710f8..e1567dffd60c90295dd9d1f28f03e4442cb7da6a 100644
--- a/module/VuFind/src/VuFind/RecordDriver/SolrDefault.php
+++ b/module/VuFind/src/VuFind/RecordDriver/SolrDefault.php
@@ -843,7 +843,7 @@ class SolrDefault extends AbstractBase
      * Get an array of information about record holdings, obtained in real-time
      * from the ILS.
      *
-     * @param \VuFind\Account\Manager $account Account manager object
+     * @param \VuFind\Auth\Manager $account Auth manager object
      *
      * @return array
      */
diff --git a/module/VuFind/src/VuFind/RecordDriver/SolrMarc.php b/module/VuFind/src/VuFind/RecordDriver/SolrMarc.php
index 37ddcbf24db7189cec6346a3bae60280e52089ba..8feacc0be00eb9e3b0f95b1ebe0ffdf1eb270234 100644
--- a/module/VuFind/src/VuFind/RecordDriver/SolrMarc.php
+++ b/module/VuFind/src/VuFind/RecordDriver/SolrMarc.php
@@ -791,7 +791,7 @@ class SolrMarc extends SolrDefault
      * Get an array of information about record holdings, obtained in real-time
      * from the ILS.
      *
-     * @param \VuFind\Account\Manager $account Account manager object
+     * @param \VuFind\Auth\Manager $account Auth manager object
      *
      * @return array
      */
@@ -822,7 +822,7 @@ class SolrMarc extends SolrDefault
     /**
      * Get a link for placing a title level hold.
      *
-     * @param \VuFind\Account\Manager $account Account manager object
+     * @param \VuFind\Auth\Manager $account Auth manager object
      *
      * @return mixed A url if a hold is possible, boolean false if not
      * @access protected
diff --git a/module/VuFind/src/VuFind/RecordDriver/WorldCat.php b/module/VuFind/src/VuFind/RecordDriver/WorldCat.php
index 8e23d96d030cd6d8e301be50efdd36f2a7221a14..f0e03966b68c460ac17cfafef9a310d066f28d60 100644
--- a/module/VuFind/src/VuFind/RecordDriver/WorldCat.php
+++ b/module/VuFind/src/VuFind/RecordDriver/WorldCat.php
@@ -69,7 +69,7 @@ class WorldCat extends SolrMarc
      * Get an array of information about record holdings, obtained in real-time
      * from the ILS.
      *
-     * @param \VuFind\Account\Manager $account Account manager object
+     * @param \VuFind\Auth\Manager $account Auth manager object
      *
      * @return array
      */
diff --git a/module/VuFind/src/VuFind/Search/Favorites/Results.php b/module/VuFind/src/VuFind/Search/Favorites/Results.php
index d523774fd4bef591f6a1a7cd86d6282ebb8293cb..ca5f2aa315bfb45a21666da0c276c98155376132 100644
--- a/module/VuFind/src/VuFind/Search/Favorites/Results.php
+++ b/module/VuFind/src/VuFind/Search/Favorites/Results.php
@@ -124,7 +124,7 @@ class Results extends BaseResults
     protected function performSearch()
     {
         $list = $this->getListObject();
-        $account = $this->getAccountManager();
+        $account = $this->getAuthManager();
         $this->user = $account ? $account->isLoggedIn() : false;
 
         // Make sure the user and/or list objects make it possible to view
diff --git a/module/VuFind/src/VuFind/Search/Favorites/Params.php b/module/VuFind/src/VuFind/Search/Favorites/Params.php
index e4154c43d5f190f28e6ea684aa3774ea95085241..d71072c99aa0ed7c64bbc461042daef7b0ef01f4 100644
--- a/module/VuFind/src/VuFind/Search/Favorites/Params.php
+++ b/module/VuFind/src/VuFind/Search/Favorites/Params.php
@@ -88,9 +88,9 @@ class Params extends BaseParams
     /**
      * Get account manager.
      *
-     * @return \VuFind\Account\Manager
+     * @return \VuFind\Auth\Manager
      */
-    public function getAccountManager()
+    public function getAuthManager()
     {
         return $this->account;
     }
@@ -98,11 +98,11 @@ class Params extends BaseParams
     /**
      * Inject dependency: account manager.
      *
      * @param \VuFind\Account\Manager $account Account manager object.
      *
      * @return void
      */
-    public function setAccountManager($account)
+    public function setAuthManager($account)
     {
         $this->account = $account;
     }
@@ -98,11 +98,11 @@ class Params extends BaseParams
      * Inject dependency: account manager.
      *
-     * @param \VuFind\Account\Manager $account Account manager object.
+     * @param \VuFind\Auth\Manager $account Auth manager object.
      *
      * @return void